OC.L10N.register(
    "settings",
    {
    "No user supplied" : "Käyttäjää ei määritetty",
    "Authentication error" : "Tunnistautumisvirhe",
    "Wrong admin recovery password. Please check the password and try again." : "Väärä ylläpitäjän salasana. Tarkista salasana ja yritä uudelleen.",
    "Backend doesn't support password change, but the user's encryption key was successfully updated." : "Taustaosa ei tue salasanan vaihtoa, mutta käyttäjän salausavain päivitettiin onnistuneesti.",
    "Unable to change password" : "Salasanan vaihto ei onnistunut",
    "%s password changed successfully" : "%s salasana vaihdettiin onnistuneesti",
    "Couldn't send reset email. Please contact your administrator." : "Palautussähköpostin lähettäminen ei onnistunut. Ota yhteys ylläpitäjään.",
    "cURL is using an outdated %s version (%s). Please update your operating system or features such as %s will not work reliably." : "cURL käyttää vanhentunutta %s-versiota (%s). Päivitä käyttöjärjestelmäsi tai ominaisuudet kuten %s eivät toimi luotettavasti.",
    "Group already exists." : "Ryhmä on jo olemassa.",
    "Unable to add group." : "Ryhmän lisääminen ei onnistunut.",
    "Unable to delete group." : "Ryhmän poistaminen ei onnistunut.",
    "Saved" : "Tallennettu",
    "log-level out of allowed range" : "lokitaso ei sallittujen rajojen sisäpuolella",
    "test email settings" : "testaa sähköpostiasetukset",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Sähköpostia lähettäessä tapahtui virhe. Tarkista asetukset. (Virhe: %s)",
    "Email sent" : "Sähköposti lähetetty",
    "You need to set your user email before being able to send test emails." : "Aseta sähköpostiosoite, jotta voit testata sähköpostin toimivuutta.",
    "Your %s account was created" : "%s-tilisi luotiin",
    "Invalid mail address" : "Virheellinen sähköpostiosoite",
    "A user with that name already exists." : "Käyttäjä samalla nimellä on jo olemassa.",
    "Unable to create user." : "Käyttäjän luominen ei onnistunut.",
    "Unable to delete user." : "Käyttäjän poistaminen ei onnistunut.",
    "Forbidden" : "Estetty",
    "Invalid user" : "Virheellinen käyttäjä",
    "Unable to change mail address" : "Sähköpostiosoitteen vaihtaminen ei onnistunut",
    "Email has been changed successfully." : "Sähköpostiosoite vaihdettiin onnistuneesti.",
    "Your full name has been changed." : "Koko nimesi on muutettu.",
    "Unable to change full name" : "Koko nimen muuttaminen epäonnistui",
    "%s email address confirm" : "%s sähköpostiosoite vahvistus",
    "Couldn't send email address change confirmation mail. Please contact your administrator." : "Ei voitu lähettää sähköpostiosoitteen vaihtamisen vahvistusta. Ole hyvä ja ota yhteyttä järjestelmänvalvojaan.",
    "%s email address changed successfully" : "%s sähköpostiosoite vaihdettu onnistuneesti",
    "Couldn't send email address change notification mail. Please contact your administrator." : "Ei voitu lähettää sähköpostiosoitteen vaihtamisen ilmoitusta. Ole hyvä ja ota yhteyttä järjestelmänvalvojaan.",
    "Unable to enable/disable user." : "Ei voitu ottaa käyttöön tai poistaa käytöstä käyttäjää",
    "Create" : "Luo",
    "Change" : "Muuta",
    "Delete" : "Poista",
    "Share" : "Jaa",
    "APCu" : "APCu",
    "Redis" : "Redis",
    "Language changed" : "Kieli on vaihdettu",
    "Invalid request" : "Virheellinen pyyntö",
    "Admins can't remove themself from the admin group" : "Ylläpitäjät eivät poistaa omia tunnuksiaan ylläpitäjien ryhmästä",
    "Unknown user" : "Tuntematon käyttäjä",
    "Couldn't remove app." : "Sovelluksen poistaminen epäonnistui.",
    "Official" : "Virallinen",
    "Approved" : "Hyväksytty",
    "All" : "Kaikki",
    "Enabled" : "Käytössä",
    "Not enabled" : "Ei käytössä",
    "No apps found for your version" : "Sovelluksia ei löytynyt versiollesi",
    "The app will be downloaded from the app store" : "Sovellus ladataan sovelluskaupasta",
    "Official apps are developed by and within the ownCloud community. They offer functionality central to ownCloud and are ready for production use." : "Viralliset sovellukset kehitetään ownCloud-yhteisön toimesta. Sovellukset tarjoavat lisäominaisuuksia ownCloudin keskeisiin toimintoihin liittyen ja ovat valmiita tuotantokäyttöön.",
    "Approved apps are developed by trusted developers and have passed a cursory security check. They are actively maintained in an open code repository and their maintainers deem them to be stable for casual to normal use." : "Hyväksytyt sovellukset on kehitetty luotettujen kehittäjien toimesta. Hyväksytyille sovelluksille on suoritettu pintapuolinen turvallisuustarkastus. Sovelluksia ylläpidetään avoimen koodin tietovarastoissa. Sovellusten kehittäjät mieltävät sovellukset vakaiksi ja valmiiksi tavalliseen käyttöön.",
    "This app is not checked for security issues and is new or known to be unstable. Install at your own risk." : "Tätä sovellusta ei ole tarkistettu tietoturvauhkien varalta. Sovellus on uusi ja mahdollisesti tiedostettu epävakaaksi. Asenna omalla vastuulla.",
    "Please wait...." : "Odota hetki...",
    "Error while disabling app" : "Virhe poistaessa sovellusta käytöstä",
    "Disable" : "Poista käytöstä",
    "Enable" : "Käytä",
    "Error while enabling app" : "Virhe ottaessa sovellusta käyttöön",
    "Error: this app cannot be enabled because it makes the server unstable" : "Virhe: tätä sovellusta ei voi ottaa käyttöön, koska se tekee palvelimesta epävakaan",
    "Error: could not disable broken app" : "Virhe: rikkinäisen sovelluksen poistaminen käytöstä ei onnistunut",
    "Error while disabling broken app" : "Virhe rikkinäistä sovellusta käytöstä poistaessa",
    "Updating...." : "Päivitetään...",
    "Error while updating app" : "Virhe sovellusta päivittäessä",
    "Updated" : "Päivitetty",
    "Uninstalling ...." : "Poistetaan asennusta....",
    "Error while uninstalling app" : "Virhe sovellusta poistaessa",
    "Uninstall" : "Poista asennus",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Tämä sovellus on otettu käyttöön, mutta se vaatii päivityksen. Sinut ohjataan päivityssivulle viiden sekunnin kuluttua.",
    "App update" : "Sovelluspäivitys",
    "Experimental" : "Kokeellinen",
    "No apps found for {query}" : "Haulla {query} ei löytynyt sovelluksia",
    "Migration in progress. Please wait until the migration is finished" : "Migraatio on kesken. Odota kunnes migraatio valmistuu",
    "Migration started …" : "Migraatio käynnistyi…",
    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Tapahtu virhe. Lähetä ASCII-koodattu PEM-varmenne.",
    "Valid until {date}" : "Kelvollinen {date} asti",
    "Disconnect" : "Katkaise yhteys",
    "Sending..." : "Lähetetään...",
    "An error occurred: {message}" : "Tapahtui virhe: {message}",
    "Select a profile picture" : "Valitse profiilikuva",
    "Very weak password" : "Erittäin heikko salasana",
    "Weak password" : "Heikko salasana",
    "So-so password" : "Kohtalainen salasana",
    "Good password" : "Hyvä salasana",
    "Strong password" : "Vahva salasana",
    "Groups" : "Ryhmät",
    "Unable to delete {objName}" : "Kohteen {objName} poistaminen epäonnistui",
    "Error creating group: {message}" : "Virhe ryhmää luotaessa: {message}",
    "A valid group name must be provided" : "Anna kelvollinen ryhmän nimi",
    "deleted {groupName}" : "poistettu {groupName}",
    "undo" : "kumoa",
    "Delete group" : "Poista ryhmä",
    "never" : "ei koskaan",
    "deleted {userName}" : "poistettu {userName}",
    "add group" : "lisää ryhmä",
    "Invalid quota value \"{val}\"" : "Virheellinen kiintiöarvo \"{val}\"",
    "enabled" : "Käytössä",
    "disabled" : "Poissa käytöstä",
    "User {uid} has been {state}!" : "Käyttäjä {uid} on asetettu {state}!",
    "no group" : "ei ryhmää",
    "Changing the password will result in data loss, because data recovery is not available for this user" : "Salasanan muuttaminen johtaa tietojen häviämiseen, koska tietojen palautusta ei ole käytettävissä tämän käyttäjän kohdalla",
    "Password successfully changed" : "Salasana muutettu onnistuneesti",
    "A valid username must be provided" : "Anna kelvollinen käyttäjätunnus",
    "Error creating user: {message}" : "Virhe käyttäjää luotaessa: {message}",
    "A valid password must be provided" : "Anna kelvollinen salasana",
    "A valid email must be provided" : "Tarvitaan kelvollinen sähköpostiosoite",
    "Use the following link to confirm your changes to the email address: {link}" : "Käytä oheistä linkkiä vahvistaaksesi muutoksesi sähköpostiosoitteseen: {link}",
    "Email address changed to {mailAddress} successfully." : "Uusi sähköpostiosoite {mailAddress} vaihdettiin onnistuneesti.",
    "Cheers!" : "Kiitos!",
    "Hey there,\n\njust letting you know that you now have an %s account.\n\nYour username: %s\nAccess it: %s\n\n" : "Hei\n\nSinulla on nyt %s-tili.\n\nKäyttäjätunnuksesi: %s\nAloita käyttö: %s\n\n",
    "Language" : "Kieli",
    "Apps Management" : "Sovellushallinta",
    "Developer documentation" : "Kehittäjädokumentaatio",
    "by %s" : "tekijä %s",
    "%s-licensed" : "%s -lisensoitu",
    "Documentation:" : "Ohjeistus:",
    "User documentation" : "Käyttäjädokumentaatio",
    "Admin documentation" : "Ylläpitäjän ohjeistus",
    "Visit website" : "Käy verkkosivustolla",
    "Report a bug" : "Ilmoita viasta",
    "Show description …" : "Näytä kuvaus…",
    "Hide description …" : "Piilota kuvaus…",
    "This app has no minimum ownCloud version assigned. This will be an error in ownCloud 11 and later." : "Tälle sovellukselle ei ole määritelty ownCloudin vähimmäisversiota. Tämä johtaa virheeseen ownCloud 11:stä alkaen.",
    "This app has no maximum ownCloud version assigned. This will be an error in ownCloud 11 and later." : "Tälle sovellukselle ei ole määritelty ownCloudin enimmäisversiota. Tämä johtaa virheeseen ownCloud 11:stä alkaen.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Tätä sovellusta ei voi asentaa, koska seuraavat riippuvuudet eivät täyty:",
    "Enable only for specific groups" : "Salli vain tietyille ryhmille",
    "Uninstall App" : "Poista sovelluksen asennus",
    "Show enabled apps" : "Näytä käyttöönotetut sovellukset",
    "Show disabled apps" : "Näytä käytöstä poistetut sovellukset",
    "Cron" : "Cron",
    "Last cron job execution: %s." : "Viimeisin cron-työn suoritus: %s.",
    "Last cron job execution: %s. Something seems wrong." : "Viimeisin cron-työn suoritus: %s. Jokin vaikuttaa menneen pieleen.",
    "Cron was not executed yet!" : "Cronia ei suoritettu vielä!",
    "Open documentation" : "Avaa dokumentaatio",
    "Execute one task with each page loaded" : "Suorita yksi tehtävä jokaista ladattua sivua kohden",
    "cron.php is registered at a webcron service to call cron.php every 15 minutes over http." : "cron.php kutsuu webcron-palvelun kautta cron.php:ta  15 minuutin välein http:tä käyttäen.",
    "Use system's cron service to call the cron.php file every 15 minutes." : "Käytä järjestelmän cron-palvelua cron.php-tiedoston kutsumista varten 15 minuutin välein.",
    "SSL Root Certificates" : "SSL-juurivarmenteet",
    "Common Name" : "Yleinen nimi",
    "Valid until" : "Kelvollinen",
    "Issued By" : " Myöntänyt",
    "Valid until %s" : "Kelvollinen %s asti",
    "Import root certificate" : "Tuo juurivarmenne",
    "Server-side encryption" : "Palvelinpään salaus",
    "Enable server-side encryption" : "Käytä palvelinpään salausta",
    "Please read carefully before activating server-side encryption: " : "Lue tarkasti, ennen kuin otat palvelinpään salauksen käyttöön:",
    "Encryption alone does not guarantee security of the system. Please see ownCloud documentation for more information about how the encryption app works, and the supported use cases." : "Salaaminen pelkästään ei takaa järjestelmän tietoturvaa. Tutustu ownCloudin dokumentaation saadaksesi lisätietoja salaussovelluksen toiminnasta ja tuetuista käyttötapauksista.",
    "Be aware that encryption always increases the file size." : "Ota huomioon, että salaus kasvattaa aina tiedostojen kokoa.",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Säännöllisten varmuuskopioiden ottaminen on erittäin tärkeää. Jos olet ottanut salauksen käyttöön, huolehdi salausavainten varmuuskopioinnista.",
    "This is the final warning: Do you really want to enable encryption?" : "Tämä on viimeinen varoitus: haluatko varmasti ottaa salauksen käyttöön?",
    "Enable encryption" : "Käytä salausta",
    "No encryption module loaded, please enable an encryption module in the app menu." : "Salausmoduulia ei ole käytössä. Ota salausmoduuli käyttöön sovellusvalikosta.",
    "Select default encryption module:" : "Valitse oletuksena käytettävä salausmoduuli:",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "Sinun täytyy siirtää salausavaimet vanhasta salaustekniikasta (ownCloud <= 8.0) uuteen. Ota \"Default encryption module\" käyttöön ja suorita komento 'occ encryption:migrate'",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "Sinun täytyy siirtää salausavaimet vanhasta salaustekniikasta (ownCloud <= 8.0) uuteen.",
    "Start migration" : "Käynnistä migraatio",
    "Sharing" : "Jakaminen",
    "Allow apps to use the Share API" : "Salli sovellusten käyttää jakamisen ohjelmointirajapintaa",
    "Allow users to share via link" : "Salli käyttäjien jakaa linkkien kautta",
    "Allow public uploads" : "Salli julkiset lähetykset",
    "Set default expiration date" : "Aseta oletusvanhenemispäivä",
    "Expire after " : "Vanhenna",
    "days" : "päivän jälkeen",
    "Allow users to send mail notification for shared files" : "Salli käyttäjien lähettää sähköposti-ilmoituksia jaetuista tiedostoista",
    "Allow users to share file via social media" : "Salli käyttäjien jakaa tiedosto sosiaalisessa mediassa",
    "Allow resharing" : "Salli uudelleenjakaminen",
    "Allow sharing with groups" : "Salli jakaminen ryhmien kanssa",
    "Restrict users to only share with users in their groups" : "Salli käyttäjien jakaa vain omassa ryhmässä olevien henkilöiden kesken",
    "Allow users to send mail notification for shared files to other users" : "Salli käyttäjien lähettää muille käyttäjille sähköpostitse ilmoitus jaetuista tiedostoista",
    "Exclude groups from sharing" : "Kiellä ryhmiä jakamasta",
    "These groups will still be able to receive shares, but not to initiate them." : "Nämä ryhmät kykenevät vastaanottamaan jakoja, mutta eivät kuitenkaan itse pysty luoda jakoja.",
    "Allow username autocompletion in share dialog. If this is disabled the full username needs to be entered." : "Salli käyttäjätunnuksen automaattinen täydentäminen jakamisikkunnassa. Jos tämä asetus on pois käytöstä, tulee käyttäjätunnus kirjoittaa kokonaan itse.",
    "None" : "Ei mitään",
    "Save" : "Tallenna",
    "Everything (fatal issues, errors, warnings, info, debug)" : "Kaikki (vakavat ongelmat, virheet, varoitukset, tiedot, vianjäljitys)",
    "Info, warnings, errors and fatal issues" : "Tiedot, varoitukset, virheet ja vakavat ongelmat",
    "Warnings, errors and fatal issues" : "Varoitukset, virheet ja vakavat ongelmat",
    "Errors and fatal issues" : "Virheet ja vakavat ongelmat",
    "Fatal issues only" : "Vain vakavat ongelmat",
    "Log" : "Loki",
    "What to log" : "Mitä kerätään lokiin",
    "Download logfile (%s)" : "Lataa lokitiedosto (%s)",
    "The logfile is bigger than 100 MB. Downloading it may take some time!" : "Lokitiedosto on kooltaan yli 100 megatavua. Sen lataaminen saattaa kestää hetken.",
    "Login" : "Kirjaudu",
    "NT LAN Manager" : "NT LAN Manager",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "Email server" : "Sähköpostipalvelin",
    "This is used for sending out notifications." : "Tätä käytetään ilmoitusten lähettämiseen.",
    "Send mode" : "Lähetystila",
    "Encryption" : "Salaus",
    "From address" : "Lähettäjän osoite",
    "Authentication method" : "Tunnistautumistapa",
    "Authentication required" : "Tunnistautuminen vaaditaan",
    "Server address" : "Palvelimen osoite",
    "Port" : "Portti",
    "Credentials" : "Tilitiedot",
    "SMTP Username" : "SMTP-käyttäjätunnus",
    "SMTP Password" : "SMTP-salasana",
    "Store credentials" : "Säilytä tilitiedot",
    "Test email settings" : "Testaa sähköpostiasetukset",
    "Send email" : "Lähetä sähköpostiviesti",
    "Security & setup warnings" : "Turvallisuus- ja asetusvaroitukset",
    "The Read-Only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Vain luku -asetukset on otettu käyttöön. Tämä estää joidenkin asetusten määrittämisen selainkäyttöliittymän kautta. Lisäksi kyseinen tiedostoon tulee asettaa kirjoitusoikeus käsin joka päivityksen yhteydessä.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Tämä johtuu todennäköisesti välimuistista tai kiihdyttimestä kuten Zend OPcachesta tai eAcceleratorista.",
    "%1$s below version %2$s is installed, for stability and performance reasons we recommend updating to a newer %1$s version." : "%1$s alle version %2$s on asennettu.  Vakauden ja suorituskyvyn vuoksi suosittelemme päivittämään uudempaan %1$s-versioon.",
    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "PHP-moduuli \"fileinfo\" puuttuu. Sen käyttö on erittäin suositeltavaa, jotta MIME-tyypin havaitseminen onnistuu parhaalla mahdollisella tavalla.",
    "System locale can not be set to a one which supports UTF-8." : "Järjestelmän maa-asetusta ei voi asettaa UTF-8:aa tukevaksi.",
    "This means that there might be problems with certain characters in file names." : "Tämä tarkoittaa, että tiettyjen merkkien kanssa tiedostojen nimissä saattaa olla ongelmia.",
    "We strongly suggest installing the required packages on your system to support one of the following locales: %s." : "Suosittelemme asentamaan vaaditut paketit järjestelmään, jotta järjestelmässä on tuki yhdelle seuraavista maa-asetuksista: %s.",
    "SQLite is used as database. For larger installations we recommend to switch to a different database backend." : "SQLitea käytetään tietokantana. Suuria asennuksia varten on suositeltavaa vaihtaa muuhun tietokantaan.",
    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Varsinkin työpöytäsovelluksen tiedostosynkronointia käyttäessä SQLiten käyttö ei ole suositeltavaa.",
    "It was not possible to execute the cronjob via CLI. The following technical errors have appeared:" : "Cron-työn suorittaminen komentorivin kautta ei onnistunut. Ilmeni seuraavia teknisiä virheitä:",
    "All checks passed." : "Läpäistiin kaikki tarkistukset.",
    "System Status" : "Järjestelmän tila",
    "Tips & tricks" : "Vinkit",
    "How to do backups" : "Kuinka tehdä varmuuskopioita",
    "Performance tuning" : "Suorituskyvyn hienosäätö",
    "Improving the config.php" : "Config.php-tiedoston parantaminen",
    "Theming" : "Teemojen käyttö",
    "Hardening and security guidance" : "Turvaamis- ja tietoturvaopas",
    "Get the apps to sync your files" : "Aseta sovellukset synkronoimaan tiedostosi",
    "Desktop client" : "Työpöytäsovellus",
    "Android app" : "Android-sovellus",
    "iOS app" : "iOS-sovellus",
    "If you want to support the project\n\t\t\t<a href=\"https://owncloud.org/contribute\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">join development</a>\n\t\t\tor\n\t\t\t<a href=\"https://owncloud.org/promote\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">spread the word</a>!" : "Jos haluat tukea projektia,\n\t\t\t<a href=\"https://owncloud.org/contribute\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">osallistu kehitykseen</a>\n\t\t\ttai\n\t\t\t<a href=\"https://owncloud.org/promote\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">levitä sanaa</a>!",
    "Show First Run Wizard again" : "Näytä ensimmäisen käyttökerran avustaja uudelleen",
    "Add" : "Lisää",
    "Profile picture" : "Profiilikuva",
    "Upload new" : "Lähetä uusi",
    "Select from Files" : "Valitse tiedostosovelluksesta",
    "Remove image" : "Poista kuva",
    "png or jpg, max. 20 MB" : "png tai jpg, korkeintaan 20 Mt",
    "Picture provided by original account" : "Kuvan tarjoaa alkuperäinen tili",
    "Cancel" : "Peru",
    "Choose as profile picture" : "Valitse profiilikuvaksi",
    "Full name" : "Koko nimi",
    "No display name set" : "Näyttönimeä ei ole asetettu",
    "Email" : "Sähköpostiosoite",
    "Your email address" : "Sähköpostiosoitteesi",
    "For password recovery and notifications" : "Salasanan nollausta ja ilmoituksia varten",
    "No email address set" : "Sähköpostiosoitetta ei ole asetettu",
    "You are member of the following groups:" : "Olet jäsenenä seuraavissa ryhmissä:",
    "Password" : "Salasana",
    "Unable to change your password" : "Salasanaasi ei voitu vaihtaa",
    "Current password" : "Nykyinen salasana",
    "New password" : "Uusi salasana",
    "Change password" : "Vaihda salasana",
    "Help translate" : "Auta kääntämisessä",
    "You are using %s" : "Käyttämäsi tila on %s",
    "You are using %s of %s (%s %%)" : "Käyttämäsi tila on %s/%s (%s %%)",
    "Developed by the {communityopen}ownCloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose}." : "Kehityksestä on vastannut {communityopen}ownCloud-yhteisö{linkclose}, {githubopen}lähdekoodi{linkclose} on {licenseopen}<abbr title=\"Affero General Public License\">AGPL-lisensoitu</abbr>{linkclose}.",
    "Sessions" : "Istunnot",
    "Browser" : "Selain",
    "Most recent activity" : "Viimeisimmät toimet",
    "You've linked these apps." : "Olet linkittänyt nämä sovellukset.",
    "Name" : "Nimi",
    "App name" : "Sovelluksen nimi",
    "Use the credentials below to configure your app or device." : "Käytä alla olevia kirjautumistietoja määrittääksesi sovelluksesi tai laitteen.",
    "Username" : "Käyttäjätunnus",
    "Done" : "Valmis",
    "Version" : "Versio",
    "New Password" : "Uusi salasana",
    "Personal" : "Henkilökohtainen",
    "Admin" : "Ylläpito",
    "Settings" : "Asetukset",
    "Show enabled/disabled option" : "Näytä käytössä/ei käytössä vaihtoehto",
    "Show storage location" : "Näytä tallennustilan sijainti",
    "Show last log in" : "Näytä viimeisin sisäänkirjautuminen",
    "Show user backend" : "Näytä käyttäjätaustaosa",
    "Show email address" : "Näytä sähköpostiosoite",
    "E-Mail" : "Sähköposti",
    "Admin Recovery Password" : "Ylläpitäjän palautussalasana",
    "Enter the recovery password in order to recover the users files during password change" : "Anna palautussalasana, jotta käyttäjien tiedostot on mahdollista palauttaa salasanan muuttamisen yhteydessä",
    "Add Group" : "Lisää ryhmä",
    "Group" : "Ryhmä",
    "Everyone" : "Kaikki",
    "Admins" : "Ylläpitäjät",
    "Default Quota" : "Oletuskiintiö",
    "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "Määritä tallennustilan kiintiö (esim. \"512 MB\" tai \"12 GB\")",
    "Unlimited" : "Rajoittamaton",
    "Other" : "Muu",
    "Full Name" : "Koko nimi",
    "Group Admin for" : "Ryhmäylläpitäjä kohteille",
    "Quota" : "Kiintiö",
    "Storage Location" : "Tallennustilan sijainti",
    "User Backend" : "Käyttäjätaustaosa",
    "Last Login" : "Viimeisin kirjautuminen",
    "change full name" : "muuta koko nimi",
    "set new password" : "aseta uusi salasana",
    "change email address" : "vaihda sähköpostiosoite",
    "Default" : "Oletus"
},
"nplurals=2; plural=(n != 1);");
